# abqpy docs

This is the source for the abqpy documentation. The documentation is built using [Sphinx](http://www.sphinx-doc.org/en/master/).

## Build the docs

To build the docs, you will need to have [Sphinx](http://www.sphinx-doc.org/en/master/) installed. You can install it using pip:

```bash
pip install sphinx
```

Once you have Sphinx installed, you can build the docs by running the following command from the root of the repository:

```bash
make html
```

This will build the docs and place them in the `build` directory. You can then open the `index.html` file in your browser to view the docs.

## Contribute

If you would like to contribute to the documentation, you can do so by editing the `.rst` files. You can then build the docs and view them locally to make sure they look correct. Once you are satisfied with your changes, you can submit a pull request.
